import matplotlib.pyplot as plt
import numpy as np
from scipy.constants import k, e


plt.rc('font', size=12)
plt.rc('lines', linewidth=1.6)

T = np.logspace(3, 5)
E = np.array([0.000000, 8.838528, 8.895698, 19.883893, 19.884040, 24.050317, 27.061641,\
 27.081703, 30.997044, 30.997059, 31.507742, 31.507984, 32.907632, 34.282086, 34.291429])

Z = np.zeros(len(T))
w = np.zeros((len(T), len(E)))
for i in range(len(T)):
	Z[i] = (sum(np.exp(-E*e / (k * T[i]))))
	for j in range(len(E)):
		w[i, j] = (1/Z[i] * np.exp(-E[j]*e / (k * T[i])))


plt.figure(figsize=(6.8,7))
plt.title("Rozdělovací funkce Si IV")
for i in range(len(w[0,:])):
	plt.plot(T, w[:,i], label="{0:.5f}".format(E[i]))
plt.xlabel("$T$ [K]")
plt.ylabel("$w$")
plt.xscale("log")
plt.legend(loc="center left")
plt.savefig("du4_rozdelovaci_fce.png", dpi=100)
plt.close()

plt.figure(figsize=(6.8,5))
plt.title("Partiční funkce Si IV")
plt.plot(T, Z)
plt.xlabel("$T$ [K]")
plt.ylabel("$\,Z$")
plt.xscale("log")
plt.savefig("du4_particni_fce.png", dpi=100)

