from scipy.integrate import quad
from scipy.constants import k, hbar, m_p
import numpy as np
import matplotlib.pyplot as plt


r0 = 65e-12
m = 14 * m_p
mu = m/2
I = mu * r0**2
T = np.logspace(0, 3)
J = np.linspace(0, 1e3, 1000)

def fun(j, T):
    return (2*j+1)*np.exp(-(hbar**2*j*(j+1)/(2*I*k*T)))

INT, SUM = np.zeros(len(T)), np.zeros(len(T))

for t in range(len(T)):
    for j in J:
        SUM[t] += fun(j, T[t])
    INT[t] = quad(fun, 0, np.inf, args=T[t])[0]
LOW_TEMP = 1 + 3 * np.exp(-hbar**2/(I*k*T))

plt.plot(T, SUM, 'o', label="suma")
plt.plot(T, INT, label="integrál")
plt.plot(T, LOW_TEMP, label="nízké teploty")
plt.xscale("log")
plt.yscale("log")
plt.xlabel("$T$ [K]")
plt.ylabel("$Z$")
plt.legend()
plt.savefig("du8_sum_to_int.png")
